# Changelog

## 2.0.0

Jul 23, 2017

- **NEW**: Add support for X11 color names.  Convert them to hex on color scheme load.
- **NEW**: Handle `popupCss` and `phantomCss`. Inject them if they are missing.
- **NEW**: Require `wxPython` 4+ and rework code to use it and support Python 2.7 and 3.4+.
- **NEW**: Remove importing and exporting of JSON color schemes.
- **FIX**: Multiple Ubuntu dock icons (possibly similar issue in other Linux distros).

## 1.0.0

- **NEW**: Initial release.
